pub struct Profile {
pub username: Option<String>,
pub email: Option<String>,
pub name: Option<String>,
}Expand description
Profile : The profile associated with a Tapis identity. NOTE -the fields in the Profile object are populated on a best-effort basis and should not be relied upon. Only the username field is guaranteed to be populated.
Fields
username: Option<String>The username associated with the profile.
email: Option<String>The email address associated with the profile.
name: Option<String>The full name of the user.
Implementations